==> gbsite-1.1.1.tar.gz: gbsite/templates/gb/gb_eventspage.php <==
<table cellpadding="4" cellspacing="0" border="0" width="100%">
<tr>
<td colspan="3"><font face="<?= $font_1 ?>" size="2">Come see us at the following shows and events!</font><br><br></td>
</tr>
<!-- spacer -->
<tr>
<td colspan="3"><img src="<?= $image_path ?>/shim.gif" width="1" height="5"></td>
</tr>
<tr>
<td><font face="<?= $font_1 ?>" size="2"><a target="_blank" href="http://www.linuxworldexpo.com/">Linux World Expo</a></td>
<td><font face="<?= $font_1 ?>" size="2">January 30- February 2, 2001</font></td>
<td><font face="<?= $font_1 ?>" size="2">New York</font></td>
</tr>
<tr>
<td colspan="3"><img src="<?= $image_path ?>/shim.gif" width="10" height="1"><font face="<?= $font_1 ?>" size="2">Come to the Great Bridge booth at #1813.</font></td>
</tr>
<!-- spacer -->
<tr>
<td colspan="3"><img src="<?= $image_path ?>/shim.gif" width="1" height="5"></td>
</tr>
<!-- spacer -->
<tr bgcolor="<?= $color_7 ?>">
<td colspan="3"><img src="<?= $image_path ?>/shim.gif" width="1" height="5"></td>
</tr>
<tr bgcolor="<?= $color_7 ?>">
<td><font face="<?= $font_1 ?>" size="2"><a target="_blank" href="http://www.kingbird.com/ebusiness/">eBusiness Expo</a></font></td>
<td><font face="<?= $font_1 ?>" size="2">June 12-14, 2001</font></td>
<td><font face="<?= $font_1 ?>" size="2">San Jose</font></td>
</tr>
<!-- spacer -->
<tr>
<td colspan="3"><img src="<?= $image_path ?>/shim.gif" width="1" height="5"></td>
</tr>
<tr>
<td><font face="<?= $font_1 ?>" size="2"><a target="_blank" href="http://conferences.oreilly.com/">O'Reilly Open Source Convention</a></font></td>
<td><font face="<?= $font_1 ?>" size="2">July 23-26, 2001</font></td>
<td><font face="<?= $font_1 ?>" size="2">San Diego</font></td>
</tr>
<!-- spacer -->
<tr bgcolor="<?= $color_7 ?>">
<td colspan="3"><img src="<?= $image_path ?>/shim.gif" width="1" height="5"></td>
</tr>
<tr bgcolor="<?= $color_7 ?>">
<td><font face="<?= $font_1 ?>" size="2"><a href="http://www.linuxworldexpo.com/ " target="_blank">Linux World Expo</a></font></td>
<td><font face="<?= $font_1 ?>" size="2">August 28-31, 2001</font></td>
<td><font face="<?= $font_1 ?>" size="2">San Francisco</font></td>
</tr>
<tr>
<td colspan="3"><img src="<?= $image_path ?>/shim.gif" width="10" height="1"><font face="<?= $font_1 ?>" size="2">Come to the Great Bridge booth at #337</font></td>
</tr>
</table>

==> gbsite-2.0.0.tar.gz: gbsite/templates/gb/gb_eventspage.php <==
<table cellpadding="4" cellspacing="0" border="0" width="100%">
<tr>
<td colspan="3"><font face="<?= $font_1 ?>" size="2">Come see us at the following shows and events!</font><br><br></td>
</tr>
<!-- spacer -->
<tr>
<td colspan="3"><img src="<?= $image_path ?>/shim.gif" width="1" height="5"></td>
</tr>
<tr>
<td><font face="<?= $font_1 ?>" size="2"><a target="_blank" href="http://conferences.oreilly.com/">O'Reilly Open Source Convention</a></font></td>
<td><font face="<?= $font_1 ?>" size="2">July 23-26, 2001</font></td>
<td><font face="<?= $font_1 ?>" size="2">San Diego</font></td>
</tr>
<!-- spacer -->
<tr bgcolor="<?= $color_7 ?>">
<td colspan="3"><img src="<?= $image_path ?>/shim.gif" width="1" height="5"></td>
</tr>
<tr bgcolor="<?= $color_7 ?>">
<td><font face="<?= $font_1 ?>" size="2"><a href="http://www.linuxworldexpo.com/ " target="_blank">Linux World Expo</a></font></td>
<td><font face="<?= $font_1 ?>" size="2">August 28-31, 2001</font></td>
<td><font face="<?= $font_1 ?>" size="2">San Francisco</font></td>
</tr>
<tr bgcolor="<?= $color_7 ?>">
<td colspan="3"><img src="<?= $image_path ?>/shim.gif" width="10" height="1"><font face="<?= $font_1 ?>" size="2">Come to the Great Bridge booth at #347.</font>
</td>
</tr>
<!-- spacer -->
<tr>
<td colspan="3"><img src="<?= $image_path ?>/shim.gif" width="1" height="5"></td>
</tr>
<tr>
<td><font face="<?= $font_1 ?>" size="2">Federal Open Source Conference and Expo</font></td>
<td><font face="<?= $font_1 ?>" size="2">October 3-5, 2001</font></td>
<td><font face="<?= $font_1 ?>" size="2">Washington, DC</font></td>
</tr>
</table>
